@@ -1,6 +1,6 @@
 S.n<-function(xin, h,  dist, p1, p2)
   #xin: the random sample
-  # h: the bandwidth to use in the test statistic - also conider the very first MSE optimal rule
+  # h: the bandwidth to use in the test statistic - also consider the very first MSE optimal rule
   # dist: distribution under the null
   # p1: 1st parameter of the distribution dist. In case of Normal Mixtures this is the object MW.nm7 etc
   # p2: 2nd parameter of the distribution dist.
@@ -21,6 +21,6 @@ S.n<-function(xin, h,  dist, p1, p2)
   arg2<-Epanechnikov(arg1/h)
   test.stat.tmp<-arg2 * All.Dens.Diffs
 
-  test.statistic<- sum(test.stat.tmp)
+  test.statistic<- sum(test.stat.tmp)* N * Delta^2 * h^{-1/2}
   c( test.statistic, Delta)
 }
